==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/AST/UselessTryRemover.h <==
// public class soot.dava.toolkits.base.AST.UselessTryRemover

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class eaeaaa279f59d230 soot_dava_toolkits_base_AST_ASTAnalysis
// @dep_class a4246d8bf89e3f7f soot_dava_toolkits_base_AST_UselessTryRemover

// header file dependencies
// @dep_header soot_dava_toolkits_base_AST_ASTAnalysis

#include "soot/dava/toolkits/base/AST/ASTAnalysis.h"

#ifndef _JC_soot_dava_toolkits_base_AST_UselessTryRemover_H_
#define _JC_soot_dava_toolkits_base_AST_UselessTryRemover_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_internal_AST_ASTNode$object;
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_refs	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_nonrefs	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$refs	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$refs;
typedef struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$nonrefs	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$object;

typedef const struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$vmethods	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtable	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtable;
typedef const struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtype	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_AST_UselessTryRemover$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_dava_toolkits_base_AST_UselessTryRemover$method$analyseASTNode$643e92d8bf923d1a(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object *, struct _jc_soot_dava_internal_AST_ASTNode$object *);
extern jint _jc_soot_dava_toolkits_base_AST_UselessTryRemover$method$getAnalysisDepth$e9bfa46b394f78e9(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_AST_UselessTryRemover$method_info$analyseASTNode$643e92d8bf923d1a;
extern _jc_method _jc_soot_dava_toolkits_base_AST_UselessTryRemover$method_info$getAnalysisDepth$e9bfa46b394f78e9;

// Static methods
extern struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object *_jc_soot_dava_toolkits_base_AST_UselessTryRemover$method$v$60d21a16a6716175(_jc_env *);

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$vmethods {
	void	(*analyseASTNode$643e92d8bf923d1a)(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object *, struct _jc_soot_dava_internal_AST_ASTNode$object *);
	jint	(*getAnalysisDepth$e9bfa46b394f78e9)(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object *);
};

// Vtable
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_AST_ASTAnalysis$vmethods	soot_dava_toolkits_base_AST_ASTAnalysis;
	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$vmethods	soot_dava_toolkits_base_AST_UselessTryRemover;
};

// Vtype
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$refs {
    _jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_refs	soot_dava_toolkits_base_AST_UselessTryRemover;
    _jc_soot_dava_toolkits_base_AST_ASTAnalysis$sub_refs	soot_dava_toolkits_base_AST_ASTAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_AST_ASTAnalysis$sub_nonrefs	soot_dava_toolkits_base_AST_ASTAnalysis;
    _jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_nonrefs	soot_dava_toolkits_base_AST_UselessTryRemover;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object {
	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtype	*vtype;
	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtype _jc_soot_dava_toolkits_base_AST_UselessTryRemover$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_AST_UselessTryRemover, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_AST_UselessTryRemover$class_object;

#endif	/* _JC_soot_dava_toolkits_base_AST_UselessTryRemover_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/AST/UselessTryRemover.h <==
// public class soot.dava.toolkits.base.AST.UselessTryRemover

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class eaeaaa279f59d230 soot_dava_toolkits_base_AST_ASTAnalysis
// @dep_class a4246d8bf89e3f7f soot_dava_toolkits_base_AST_UselessTryRemover

// header file dependencies
// @dep_header soot_dava_toolkits_base_AST_ASTAnalysis

#include "soot/dava/toolkits/base/AST/ASTAnalysis.h"

#ifndef _JC_soot_dava_toolkits_base_AST_UselessTryRemover_H_
#define _JC_soot_dava_toolkits_base_AST_UselessTryRemover_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_internal_AST_ASTNode$object;
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_refs	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_nonrefs	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$refs	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$refs;
typedef struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$nonrefs	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$object;

typedef const struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$vmethods	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtable	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtable;
typedef const struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtype	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_AST_UselessTryRemover$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_dava_toolkits_base_AST_UselessTryRemover$method$analyseASTNode$643e92d8bf923d1a(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object *, struct _jc_soot_dava_internal_AST_ASTNode$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_dava_toolkits_base_AST_UselessTryRemover$method$getAnalysisDepth$e9bfa46b394f78e9(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_AST_UselessTryRemover$method_info$analyseASTNode$643e92d8bf923d1a;
extern _jc_method _jc_soot_dava_toolkits_base_AST_UselessTryRemover$method_info$getAnalysisDepth$e9bfa46b394f78e9;

// Static methods
extern struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object *_jc_soot_dava_toolkits_base_AST_UselessTryRemover$method$v$60d21a16a6716175(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$vmethods {
	void	(*analyseASTNode$643e92d8bf923d1a)(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object *, struct _jc_soot_dava_internal_AST_ASTNode$object *) _JC_JCNI_ATTR;
	jint	(*getAnalysisDepth$e9bfa46b394f78e9)(_jc_env *, struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_AST_ASTAnalysis$vmethods	soot_dava_toolkits_base_AST_ASTAnalysis;
	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$vmethods	soot_dava_toolkits_base_AST_UselessTryRemover;
};

// Vtype
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$refs {
    _jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_refs	soot_dava_toolkits_base_AST_UselessTryRemover;
    _jc_soot_dava_toolkits_base_AST_ASTAnalysis$sub_refs	soot_dava_toolkits_base_AST_ASTAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_AST_ASTAnalysis$sub_nonrefs	soot_dava_toolkits_base_AST_ASTAnalysis;
    _jc_soot_dava_toolkits_base_AST_UselessTryRemover$sub_nonrefs	soot_dava_toolkits_base_AST_UselessTryRemover;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_AST_UselessTryRemover$object {
	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtype	*vtype;
	_jc_soot_dava_toolkits_base_AST_UselessTryRemover$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_AST_UselessTryRemover$vtype _jc_soot_dava_toolkits_base_AST_UselessTryRemover$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_AST_UselessTryRemover, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_AST_UselessTryRemover$class_object;

#endif	/* _JC_soot_dava_toolkits_base_AST_UselessTryRemover_H_ */
